@@ -104,6 +104,13 @@ Molecule::~Molecule ()
 void Molecule::AddChild (Object* object)
 {
 	switch (object->GetType ()) {
+	case gcu::AtomType:
+			if (object->GetParent () && object->GetParent ()->GetType () == FragmentType)
+				object = object->GetParent ();
+			else {
+				gcu::Molecule::AddChild (object);
+				break;
+			}
 	case FragmentType: {
 		Fragment *fragment = reinterpret_cast<Fragment *> (object);
 		m_Fragments.remove (fragment);
