@@ -2,7 +2,7 @@
  * Gnome Chemistry Utils
  * object.cc 
  *
- * Copyright (C) 2002-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2010 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -23,7 +23,9 @@
 #include "config.h"
 #include "object.h"
 #include "objprops.h"
+#include "dialog.h"
 #include "document.h"
+#include <glib/gi18n.h>
 #include <string>
 #include <iostream>
 #include <vector>
@@ -398,6 +400,32 @@ bool Object::BuildContextualMenu (GtkUIManager *UIManager, Object *object, doubl
 	return result | ((m_Parent)? m_Parent->BuildContextualMenu (UIManager, object, x, y): false);
 }
 
+char const *Object::HasPropertiesDialog () const
+{
+	return NULL;
+}
+
+Dialog *Object::BuildPropertiesDialog ()
+{
+	return NULL;
+}
+
+void Object::ShowPropertiesDialog ()
+{
+	const char *dlg_name = HasPropertiesDialog ();
+	if (!dlg_name)
+		return;
+	DialogOwner *owner = dynamic_cast <DialogOwner *> (this);
+	if (!owner)
+		return;
+	Dialog *dlg = owner->GetDialog (dlg_name);
+	if (!dlg)
+		dlg = BuildPropertiesDialog ();
+	if (dlg)
+		dlg->Present ();
+	
+}
+
 Object* Object::GetAtomAt (G_GNUC_UNUSED double x, G_GNUC_UNUSED double y, G_GNUC_UNUSED double z)
 {
 	return NULL;
@@ -438,6 +466,16 @@ TypeId Object::AddType (string TypeName, Object* (*Create) (), TypeId id)
 	return typedesc.Id;
 }
 
+void Object::AddAlias (TypeId id, std::string TypeName)
+{
+	if (id > TypeNames.size ())
+		return;
+	string &name = TypeNames[id];
+	if (name.length () == 0)
+		return;
+	Types[TypeName] = Types[name];
+}
+
 Object* Object::CreateObject (const string& TypeName, Object* parent)
 {
 	TypeDesc& typedesc = Types[TypeName];
@@ -654,4 +692,14 @@ void Object::SetDirty (bool dirty)
 	}
 }
 
+std::string Object::Identity ()
+{
+	return Name () + " " + GetId ();
+}
+
+std::string Object::Name ()
+{
+	return _("Object");
+}
+
 }	//	namespace gcu
