@@ -2,9 +2,9 @@
 
 /* 
  * Gnome Chemistry Utils
- * gcu/loader.h
+ * gcu/objprops.h
  *
- * Copyright (C) 2007-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2007-2009 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -41,7 +41,7 @@ The position of an object in a 2D representation.
 */
 	GCU_PROP_POS2D,
 /*!
-The position of an object in a 2D representation.
+The position of an object in a 3D representation.
 */
 	GCU_PROP_POS3D,
 	// Document properties
@@ -58,6 +58,18 @@ The z coordinate of an object
 */
 	GCU_PROP_Z,
 /*!
+The fractional x coordinate of an object
+*/
+	GCU_PROP_XFRACT,
+/*!
+The fractional y coordinate of an object
+*/
+	GCU_PROP_YFRACT,
+/*!
+The fractional z coordinate of an object
+*/
+	GCU_PROP_ZFRACT,
+/*!
 The file name.
 */
 	GCU_PROP_DOC_FILENAME,
@@ -74,10 +86,14 @@ A text added to the document as comment.
 */
 	GCU_PROP_DOC_COMMENT,
 /*!
-Who created the file.
+Who created the file or the main author.
 */
 	GCU_PROP_DOC_CREATOR,
 /*!
+Who created the file or the main author.
+*/
+	GCU_PROP_DOC_CREATOR_EMAIL,
+/*!
 The date of file creation.
 */
 	GCU_PROP_DOC_CREATION_TIME,
@@ -162,6 +178,54 @@ The Id of the object representing the products.
 The type of a reaction arrow ("double" for a reversible arrow).
 */
 	GCU_PROP_REACTION_ARROW_TYPE,
+/*!
+The a parameter of a crystal cell.
+*/
+	GCU_PROP_CELL_A,
+/*!
+The b parameter of a crystal cell.
+*/
+	GCU_PROP_CELL_B,
+/*!
+The c parameter of a crystal cell.
+*/
+	GCU_PROP_CELL_C,
+/*!
+The alpha angle of a crystal cell.
+*/
+	GCU_PROP_CELL_ALPHA,
+/*!
+The beta angle of a crystal cell.
+*/
+	GCU_PROP_CELL_BETA,
+/*!
+The gamme angle of a crystal cell.
+*/
+	GCU_PROP_CELL_GAMMA,
+/*!
+The common name of the chemical entity.
+*/
+	GCU_PROP_CHEMICAL_NAME_COMMON,
+/*!
+The IUPAC name of the chemical entity.
+*/
+	GCU_PROP_CHEMICAL_NAME_SYSTEMATIC,
+/*!
+The name of the mineral (see http://www.iucr.org/__data/iucr/cifdic_html/1/cif_core.dic/Ichemical_name_mineral.html).
+*/
+	GCU_PROP_CHEMICAL_NAME_MINERAL,
+/*!
+The name of the structure type (see http://www.iucr.org/__data/iucr/cifdic_html/1/cif_core.dic/Ichemical_name_structure_type.html).
+*/
+	GCU_PROP_CHEMICAL_NAME_STRUCTURE,
+/*!
+The name of the space group for a crystal. The Hall name is used as it is unique.
+*/
+	GCU_PROP_SPACE_GROUP,
+/*!
+The first invalid value. It might be used as an error value.
+*/
+	GCU_PROP_MAX
 };
 
 #endif	//	GCU_OBJ_PROPS_H
