@@ -79,7 +79,6 @@ gcpOrbitalProps::gcpOrbitalProps (gcp::Document *doc, gcpOrbital *orbital):
 	m_Node = NULL;
 	g_signal_connect_swapped (dialog, "focus-in-event", G_CALLBACK (gcpOrbitalProps::OnStartEditing), this);
 	g_signal_connect_swapped (dialog, "focus-out-event", G_CALLBACK (gcpOrbitalProps::OnEndEditing), this);
-	g_signal_connect_swapped (dialog, "destroy", G_CALLBACK (gcpOrbitalProps::OnEndEditing), this);
 	GtkWidget *w = GetWidget ("s-btn");
 	g_object_set_data (G_OBJECT (w), "orbital-type", GUINT_TO_POINTER (GCP_ORBITAL_TYPE_S));
 	if (m_Orbital->GetType () == GCP_ORBITAL_TYPE_S) {
@@ -113,6 +112,7 @@ gcpOrbitalProps::gcpOrbitalProps (gcp::Document *doc, gcpOrbital *orbital):
 
 gcpOrbitalProps::~gcpOrbitalProps ()
 {
+	OnEndEditing (this);
 	if (m_Node)
 		xmlFree (m_Node);
 }
@@ -140,6 +140,7 @@ void gcpOrbitalProps::OnEndEditing (gcpOrbitalProps *dlg)
 		gcu::Object *obj = dlg->m_Orbital->GetGroup ();
 		op->AddObject (obj, 1);
 		dlg->m_Doc->FinishOperation ();
+		OnStartEditing (dlg); // updates everything so that we really do incremental undo/redo
 	}
 	dlg->m_Node = NULL;
 }
@@ -202,6 +203,10 @@ void gcpOrbital::AddItem ()
 	gcp::View *view = doc->GetView ();
 	double zoom = theme->GetZoomFactor ();
 	gccv::Group *group = static_cast <gccv::Group *> (m_Atom->GetItem ());
+	if (!group) { // the atom is inside a fragment
+		gcu::Object *parent = m_Atom->GetParent ();
+		group = static_cast <gccv::Group *> (dynamic_cast <gccv::ItemClient *> (parent)->GetItem ());
+	}
 	switch (m_Type) {
 	case GCP_ORBITAL_TYPE_S: {
 		gccv::Circle *circle = new gccv::Circle (group, 0., 0., theme->GetBondLength () * fabs (m_Coef) * zoom / 2., this);
@@ -316,11 +321,11 @@ xmlNodePtr gcpOrbital::Save (xmlDocPtr xml) const
 	default:
 		break;
 	}
-	buf = g_strdup_printf("%g", m_Coef);
+	buf = g_strdup_printf ("%g", m_Coef);
 	xmlNewProp (node, reinterpret_cast <xmlChar const *> ("coef"), reinterpret_cast <xmlChar *> (buf));
 	g_free (buf);
 	if (m_Rotation != 0. && m_Type != GCP_ORBITAL_TYPE_S) {
-		buf = g_strdup_printf("%g", m_Rotation);
+		buf = g_strdup_printf ("%g", m_Rotation);
 		xmlNewProp (node, reinterpret_cast <xmlChar const *> ("rotation"), reinterpret_cast <xmlChar *> (buf));
 		g_free (buf);
 	}
