@@ -2,7 +2,7 @@
  * Gnome Chemistry Utils
  * programs/gchemtable-data.cc
  *
- * Copyright (C) 2007 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2007-2009 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -25,7 +25,6 @@
 #include <gcu/element.h>
 #include <map>
 #include <string>
-#include <goffice/math/go-math.h>
 #include <gsf/gsf-impl-utils.h>
 #include <glib/gi18n.h>
 
@@ -54,13 +53,13 @@ gct_data_preferred_fmt (G_GNUC_UNUSED GOData const *dat)
 }
 
 static char *
-gct_data_as_str (G_GNUC_UNUSED GOData const *dat)
+gct_data_serialize (G_GNUC_UNUSED GOData const *dat, G_GNUC_UNUSED gpointer data)
 {
 	return NULL;
 }
 
 static  gboolean
-gct_data_from_str (G_GNUC_UNUSED GOData *dat, G_GNUC_UNUSED char const *str)
+gct_data_unserialize (G_GNUC_UNUSED GOData *dat, G_GNUC_UNUSED char const *str, G_GNUC_UNUSED gpointer data)
 {
 	return FALSE;
 }
@@ -101,8 +100,8 @@ gct_data_scalar_class_init (GObjectClass *gobject_klass)
 	godata_klass->dup = gct_data_dup;
 	godata_klass->eq = gct_data_eq;
 	godata_klass->preferred_fmt	= gct_data_preferred_fmt;
-	godata_klass->as_str = gct_data_as_str;
-	godata_klass->from_str = gct_data_from_str;
+	godata_klass->serialize = gct_data_serialize;
+	godata_klass->unserialize = gct_data_unserialize;
 	scalar_klass->get_value = gct_data_scalar_get_value;
 	scalar_klass->get_str = gct_data_scalar_get_str;
 }
@@ -114,11 +113,11 @@ gct_data_scalar_init (G_GNUC_UNUSED GObject *obj)
 
 GSF_CLASS (GctDataScalar, gct_data_scalar,
 	   gct_data_scalar_class_init, gct_data_scalar_init,
-	   GO_DATA_SCALAR_TYPE)
+	   GO_TYPE_DATA_SCALAR)
 
 void gct_data_scalar_new (char const *name, void (*loader) (double *value))
 {
-	GctDataScalar *sc = GCT_DATA_SCALAR (g_object_new (GO_DATA_SCALAR_TYPE, NULL));
+	GctDataScalar *sc = GCT_DATA_SCALAR (g_object_new (GCT_TYPE_DATA_SCALAR, NULL));
 	sc->loader = loader;
 	GctScalars[name] = GO_DATA (sc);
 
@@ -169,6 +168,7 @@ gct_data_vector_load_values (GODataVector *dat)
 	if (dat->len > 0) {
 		int i = 0;
 		while (!go_finite (vec->data[i++]) && i < dat->len) {;}
+		i--;
 		if (i < dat->len)
 			dat->minimum = dat->maximum = vec->data[i];
 		for (; i < dat->len; i++)
@@ -227,8 +227,8 @@ gct_data_vector_class_init (GObjectClass *gobject_klass)
 	godata_klass->dup = gct_data_dup;
 	godata_klass->eq = gct_data_eq;
 	godata_klass->preferred_fmt	= gct_data_preferred_fmt;
-	godata_klass->as_str = gct_data_as_str;
-	godata_klass->from_str = gct_data_from_str;
+	godata_klass->serialize = gct_data_serialize;
+	godata_klass->unserialize = gct_data_unserialize;
 	vector_klass->load_len = gct_data_vector_load_len;
 	vector_klass->load_values = gct_data_vector_load_values;
 	vector_klass->get_value = gct_data_vector_get_value;
@@ -242,11 +242,11 @@ gct_data_vector_init (G_GNUC_UNUSED GObject *obj)
 
 GSF_CLASS (GctDataVector, gct_data_vector,
 	   gct_data_vector_class_init, gct_data_vector_init,
-	   GO_DATA_VECTOR_TYPE)
+	   GO_TYPE_DATA_VECTOR)
 
 void gct_data_vector_new (char const *name, void (*loader) (double **values, int *length))
 {
-	GctDataVector *vec = GCT_DATA_VECTOR (g_object_new (GCT_DATA_VECTOR_TYPE, NULL));
+	GctDataVector *vec = GCT_DATA_VECTOR (g_object_new (GCT_TYPE_DATA_VECTOR, NULL));
 	vec->loader = loader;
 	GctVectors[name] = GO_DATA (vec);
 }
@@ -331,8 +331,8 @@ gct_data_matrix_class_init (GObjectClass *gobject_klass)
 	godata_klass->dup = gct_data_dup;
 	godata_klass->eq = gct_data_eq;
 	godata_klass->preferred_fmt	= gct_data_preferred_fmt;
-	godata_klass->as_str = gct_data_as_str;
-	godata_klass->from_str = gct_data_from_str;
+	godata_klass->serialize = gct_data_serialize;
+	godata_klass->unserialize = gct_data_unserialize;
 	matrix_klass->load_size = gct_data_matrix_load_size;
 	matrix_klass->load_values = gct_data_matrix_load_values;
 	matrix_klass->get_value = gct_data_matrix_get_value;
@@ -346,11 +346,11 @@ gct_data_matrix_init (G_GNUC_UNUSED GObject *obj)
 
 GSF_CLASS (GctDataMatrix, gct_data_matrix,
 	   gct_data_matrix_class_init, gct_data_matrix_init,
-	   GO_DATA_MATRIX_TYPE)
+	   GO_TYPE_DATA_MATRIX)
 
 void gct_data_matrix_new (char const *name, void (*loader) (double **values, int *cols, int *rows))
 {
-	GctDataMatrix *mat = GCT_DATA_MATRIX (g_object_new (GCT_DATA_MATRIX_TYPE, NULL));
+	GctDataMatrix *mat = GCT_DATA_MATRIX (g_object_new (GCT_TYPE_DATA_MATRIX, NULL));
 	mat->loader = loader;
 	GctMatrices[name] = GO_DATA (mat);
 }
